@@ -10,6 +10,8 @@ pub trait ContainerExt {
     #[must_use]
     fn env(self, env: impl IntoIterator<Item = impl ToEnvVar>) -> Self;
     #[must_use]
+    fn env_from(self, env: impl IntoIterator<Item = impl ToEnvFrom>) -> Self;
+    #[must_use]
     fn image(self, image: impl ToString) -> Self;
     #[must_use]
     fn image_pull_policy_always(self) -> Self;
@@ -64,6 +66,11 @@ impl ContainerExt for corev1::Container {
         Self { env, ..self }
     }
 
+    fn env_from(self, env: impl IntoIterator<Item = impl ToEnvFrom>) -> Self {
+        let env_from = Some(env.into_iter().map(ToEnvFrom::to_envfrom).collect());
+        Self { env_from, ..self }
+    }
+
     fn image(self, image: impl ToString) -> Self {
         let image = Some(image.to_string());
         Self { image, ..self }
