@@ -1,10 +1,8 @@
 //
-// Copyright (c) 2021 RepliXio Ltd. All rights reserved.
+// Copyright (c) 2022 RepliXio Ltd. All rights reserved.
 // Use is subject to license terms.
 //
 
-use k8s_openapi::api::core::v1::EnvVar;
-
 use super::*;
 
 /// Builders for `corev1::EnvVar` objects
@@ -87,11 +85,11 @@ impl EnvVarExt for corev1::EnvVar {
 }
 
 pub trait ToEnvVar {
-    fn to_envvar(&self) -> EnvVar;
+    fn to_envvar(&self) -> corev1::EnvVar;
 }
 
-impl ToEnvVar for EnvVar {
-    fn to_envvar(&self) -> EnvVar {
+impl ToEnvVar for corev1::EnvVar {
+    fn to_envvar(&self) -> corev1::EnvVar {
         self.clone()
     }
 }
@@ -101,9 +99,31 @@ where
     T: std::fmt::Display,
     U: std::fmt::Display,
 {
-    fn to_envvar(&self) -> EnvVar {
+    fn to_envvar(&self) -> corev1::EnvVar {
         let (ref name, ref value) = *self;
-        EnvVar::value(name, value)
+        corev1::EnvVar::value(name, value)
+    }
+}
+
+pub trait ToEnvFrom {
+    fn to_envfrom(self) -> corev1::EnvFromSource;
+}
+
+impl ToEnvFrom for corev1::SecretEnvSource {
+    fn to_envfrom(self) -> corev1::EnvFromSource {
+        corev1::EnvFromSource {
+            secret_ref: Some(self),
+            ..corev1::EnvFromSource::default()
+        }
+    }
+}
+
+impl ToEnvFrom for corev1::ConfigMapEnvSource {
+    fn to_envfrom(self) -> corev1::EnvFromSource {
+        corev1::EnvFromSource {
+            config_map_ref: Some(self),
+            ..corev1::EnvFromSource::default()
+        }
     }
 }
 
