@@ -391,7 +391,7 @@ impl super::Kubectl {
     ) -> anyhow::Result<V>
     where
         K: Ord + ToString + std::str::FromStr + Clone,
-        K::Err: std::error::Error + Send + Sync + 'static,
+        K::Err: std::fmt::Debug + Send + Sync + 'static,
         V: ser::Serialize + de::DeserializeOwned + Clone,
         F: Fn(&BTreeMap<K, V>) -> anyhow::Result<V>,
     {
@@ -419,7 +419,7 @@ impl super::Kubectl {
     ) -> anyhow::Result<Option<V>>
     where
         K: Ord + ToString + std::str::FromStr,
-        K::Err: std::error::Error + Send + Sync + 'static,
+        K::Err: std::fmt::Debug + Send + Sync + 'static,
         V: ser::Serialize + de::DeserializeOwned,
     {
         let mut value = None;
@@ -439,7 +439,7 @@ impl super::Kubectl {
     ) -> anyhow::Result<corev1::ConfigMap>
     where
         K: Ord + ToString + std::str::FromStr,
-        K::Err: std::error::Error + Send + Sync + 'static,
+        K::Err: std::fmt::Debug + Send + Sync + 'static,
         V: ser::Serialize + de::DeserializeOwned,
     {
         // rv used to make sure that update has been applied successfully
@@ -600,14 +600,20 @@ fn try_update_json_configmap<K, V>(
 ) -> anyhow::Result<()>
 where
     K: Ord + ToString + std::str::FromStr,
-    K::Err: std::error::Error + Send + Sync + 'static,
+    K::Err: std::fmt::Debug + Send + Sync + 'static,
     V: ser::Serialize + de::DeserializeOwned,
 {
+    use anyhow::anyhow;
     use serde_json::{from_str, to_string};
     use std::any::type_name;
+
     let mut data: BTreeMap<K, V> = cm_data
         .iter()
-        .map(|(key, value)| Ok((key.parse()?, from_str(value)?)))
+        .map(|(key, value)| {
+            let key = key.parse().map_err(|e: K::Err| anyhow!("{:?}", e))?;
+            let value = from_str(value)?;
+            Ok((key, value))
+        })
         .collect::<anyhow::Result<_>>()
         .with_context(|| {
             format!(
